{ Propeller Intelligent Wireless Terminal (PWIT)

       S2 PWIT Demo #1                              

      Nicholas G. Lordi  Ver.1  December 2011

   This demo is designed to test many of the motion commands in the S2 driver set.
   It enables S2 control from PWIT, the hand held Propeller Wireless Intelligent
   Terminal, and can be used for nonautomonous control of the S2. Specific
   commands are selected, using the keypad, by entering A, B, or C followed by a  
   number 0 - 9.  A...D represent different command lists up to 10 in length.
   D is not used in this demo. The corresponding S2 program is S2_PWIT_demo1.spin.

   Note that entering '*" on the keypad will terminate the current command mode
   (A, B, or C), allowing the user to change the command mode. 
    

   S2 Command Lists

      A -                B -                          C -                 

    0 : go_forward(dist)   turn_deg_left(Angle)         wheels_now(lvel,rvel,time)                        
    1 : go_back(dist)      turn_deg_right(Angle)        AdjustLeftVelocityUp
    2 : go_left(dist)      arc_deg_left(Angle,Radius)   AdjustLeftVelocityDn
    3 : go_right(dist)     arc_deg_right(Angle,Radius)  AdjustRightVelocityUp
    4 : AdjustDistanceUp   AdjustAngleUp                AdjustRightVelocityDn
    5 : AdjustDistanceDn   AdjustAngleDn                AdjustTimeUp
    6 : AdjustSpeedUp      AdjustRadiusUp               AdjustTimeDn                               
    7 : AdjustSpeedDn      AdjustRadiusDn

    All adjustments are made by successive pressing the the indicated keys. The
    selected parameter is displayed on the LCD and updated after each key press.
    The default parameter and increment values are in the S2_PWIT_demo1.                                   
}

CON

   _clkmode = xtal1 +pll16x
   _xinfreq = 5_000_000

   XB_Rx    =  14
   XB_Tx    =  15
   XB_Baud  =  9600

   LCD_Rx  =  7
   LBaud   =  19_200
   
   KP_Tx   =  6
   KP_Baud =  9600


VAR

   
   long Value
   
   byte set, key 

OBJ

   lcd  : "LCD_DisplayDriver"
   xb   : "XBee_Object"
   kp   : "FullDuplexSerial"  


DAT

'' Labels displayed on the LCD to identify S2 operations.
   Fwrd   byte  "go_forward         ",0
   Bkwrd  byte  "go_back            ",0
   GoLft  byte  "go_left            ",0
   GoRgt  byte  "go_right           ",0
   TurLft byte  "turn_deg_left      ",0
   TurRgt byte  "turn_deg_right     ",0
   ArcLft byte  "arc_deg_left       ",0
   ArcRgt byte  "arc_deg_right      ",0
   Wheels byte  "wheels_now         ",0
   Distu  byte  "Adjust Distance Up ",0
   Distd  byte  "Adjust Distance Dn ",0
   Spdu   byte  "Adjust Speed Up    ",0
   Spdd   byte  "Adjust Speed Dn    ",0
   Angu   byte  "Adjust Angle Up    ",0
   Angd   byte  "Adjust Angle Dn    ",0
   Radu   byte  "Adjust Radius Up   ",0
   Radd   byte  "Adjust Radius Dn   ",0
   Lvelu  byte  "Adjust Left Vel Up ",0
   Lveld  byte  "Adjust Left Vel Dn ",0
   Rvelu  byte  "Adjust Right Vel Up",0
   Rveld  byte  "Adjust Right Vel Dn",0
   Timeu  byte  "Adjust TIME Up     ",0
   Timed  byte  "Adjust Time Dn     ",0  
   Dunit  byte  "        mm/2        ",0
   Aunit  byte  "        deg (0-360) ",0
   Tunit  byte  "        msec        ",0
   Sunit  byte  "        (0-15)      ",0
   Vunit  byte  "        (-255 - 255)",0
   Alabel byte  "Set A Enabled ",0
   Blabel byte  "Set B Enabled ",0
   Clabel byte  "Set C Enabled ",0
   Dlabel byte  "Set D Enabled ",0
   Minus  byte  "-",0
    

PUB Start   

   xb.start(XB_Rx, XB_Tx, 0, XB_Baud)
   lcd.Init(LCD_Rx, LBaud, true, 4)
   kp.start(KP_Tx, -1, 0, KP_Baud)
   lcd.ClearDisplay

   
   repeat  

      set := kp.rx 
      lcd.GotoRowCol(0,3)
      CASE set
        65  : lcd.OutStr(@Alabel)
              SetA       
        66  : lcd.OutStr(@Blabel)   
              SetB                                                                                                                                                                                                         
        67  : lcd.OutStr(@Clabel)
              SetC
        68  : lcd.OutStr(@Dlabel)
              SetD
                          

PRI SetA

     xb.Tx(set)
     xb.CR
     if key == 42
        key := 0
     repeat until key == 42
        key := kp.rx
        lcd.GotoRowCol(1,0)
        CASE key
          48   :  lcd.OutStr(@Fwrd)
          49   :  lcd.OutStr(@Bkwrd)
          50   :  lcd.OutStr(@GoLft)
          51   :  lcd.OutStr(@GoRgt)
          52   :  lcd.OutStr(@Distu) 
                  lcd.OutStr(@Dunit)                 
          53   :  lcd.OutStr(@Distd)
                  lcd.OutStr(@Dunit)                                     
          54   :  lcd.OutStr(@Spdu)
                  lcd.OutStr(@Sunit)
          55   :  lcd.OutStr(@Spdd)
                  lcd.OutStr(@Sunit)   
          42   :  lcd.ClearDisplay                   
                  
        lcd.GoToRowCol(2,0)  
        xb.Tx(key)
       
        if key > 51
           getData
           
PRI SetB  

     xb.Tx(set)
     xb.CR
     if key == 42
        key := 0
     repeat until key == 42
        key := kp.rx
        lcd.GotoRowCol(1,0)
        CASE key
          48   :  lcd.OutStr(@TurLft)
          49   :  lcd.OutStr(@TurRgt)
          50   :  lcd.OutStr(@ArcLft)
          51   :  lcd.OutStr(@ArcRgt)
          52   :  lcd.OutStr(@Angu) 
                  lcd.OutStr(@Aunit)                   
          53   :  lcd.OutStr(@Angd)
                  lcd.OutStr(@Aunit)                 
          54   :  lcd.OutStr(@Radu)
                  lcd.OutStr(@Dunit)
          55   :  lcd.OutStr(@Radd)
                  lcd.OutStr(@Dunit)   
          42   :  lcd.ClearDisplay
                                             
        lcd.GoToRowCol(2,0)  
        xb.Tx(key)

        if key > 51
           getData
       
      

PRI SetC  

     xb.Tx(set)
     xb.CR
     if key == 42
        key := 0
     repeat until key == 42
        key := kp.rx
        lcd.GotoRowCol(1,0)
        CASE key
          48   :  lcd.OutStr(@Wheels)
          49   :  lcd.OutStr(@Lvelu)
                  lcd.OutStr(@Vunit)
          50   :  lcd.OutStr(@Lveld)
                  lcd.OutStr(@Vunit)
          51   :  lcd.OutStr(@Rvelu)
                  lcd.OutStr(@Vunit) 
          52   :  lcd.OutStr(@Rveld)
                  lcd.OutStr(@Vunit)        
          53   :  lcd.OutStr(@Timeu)
                  lcd.OutStr(@Tunit)
          54   :  lcd.OutStr(@Timed)
                  lcd.OutStr(@Tunit)                                                       
          42   :  lcd.ClearDisplay
                                             
        lcd.GoToRowCol(2,0)  
        xb.Tx(key)
       
        if key > 48
           getData

PRI setD            
           
PRI getData

    Value := xb.RxDecTime(100)
    lcd.GotoRowCol(2,0)
    lcd.OutText(string("       "))
    lcd.GoToRowCol(2,0)
    if Value < 0
       lcd.OutStr(@Minus)
       lcd.GoToRowCol(2,1)
       lcd.OutNum(||Value)
    Else
       lcd.OutNum(Value)
    
    


    
                     